==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/managednetwork/kotlin/inputs/ScopeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetwork.kotlin.inputs

import com.pulumi.azurenative.managednetwork.inputs.ScopeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Scope of a Managed Network
 * @property managementGroups The collection of management groups covered by the Managed Network
 * @property subnets The collection of  subnets covered by the Managed Network
 * @property subscriptions The collection of subscriptions covered by the Managed Network
 * @property virtualNetworks The collection of virtual nets covered by the Managed Network
 */
public data class ScopeArgs(
    public val managementGroups: Output<List<ResourceIdArgs>>? = null,
    public val subnets: Output<List<ResourceIdArgs>>? = null,
    public val subscriptions: Output<List<ResourceIdArgs>>? = null,
    public val virtualNetworks: Output<List<ResourceIdArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetwork.inputs.ScopeArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetwork.inputs.ScopeArgs =
        com.pulumi.azurenative.managednetwork.inputs.ScopeArgs.builder()
            .managementGroups(
                managementGroups?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .subnets(
                subnets?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .subscriptions(
                subscriptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .virtualNetworks(
                virtualNetworks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ScopeArgs].
 */
@PulumiTagMarker
public class ScopeArgsBuilder internal constructor() {
    private var managementGroups: Output<List<ResourceIdArgs>>? = null

    private var subnets: Output<List<ResourceIdArgs>>? = null

    private var subscriptions: Output<List<ResourceIdArgs>>? = null

    private var virtualNetworks: Output<List<ResourceIdArgs>>? = null

    /**
     * @param value The collection of management groups covered by the Managed Network
     */
    @JvmName("aqjcfutexofrgcnr")
    public suspend fun managementGroups(`value`: Output<List<ResourceIdArgs>>) {
        this.managementGroups = value
    }

    @JvmName("urogqcfynxwnqxst")
    public suspend fun managementGroups(vararg values: Output<ResourceIdArgs>) {
        this.managementGroups = Output.all(values.asList())
    }

    /**
     * @param values The collection of management groups covered by the Managed Network
     */
    @JvmName("orhkfecxpuqbkqga")
    public suspend fun managementGroups(values: List<Output<ResourceIdArgs>>) {
        this.managementGroups = Output.all(values)
    }

    /**
     * @param value The collection of  subnets covered by the Managed Network
     */
    @JvmName("mkvfjlqlehheyhea")
    public suspend fun subnets(`value`: Output<List<ResourceIdArgs>>) {
        this.subnets = value
    }

    @JvmName("eocjfjexobvcnpcx")
    public suspend fun subnets(vararg values: Output<ResourceIdArgs>) {
        this.subnets = Output.all(values.asList())
    }

    /**
     * @param values The collection of  subnets covered by the Managed Network
     */
    @JvmName("imrlxjunhlrrlyyl")
    public suspend fun subnets(values: List<Output<ResourceIdArgs>>) {
        this.subnets = Output.all(values)
    }

    /**
     * @param value The collection of subscriptions covered by the Managed Network
     */
    @JvmName("mookkjxyteydlbmh")
    public suspend fun subscriptions(`value`: Output<List<ResourceIdArgs>>) {
        this.subscriptions = value
    }

    @JvmName("fduxjobcjwxjkoef")
    public suspend fun subscriptions(vararg values: Output<ResourceIdArgs>) {
        this.subscriptions = Output.all(values.asList())
    }

    /**
     * @param values The collection of subscriptions covered by the Managed Network
     */
    @JvmName("xaeppnalstbjmvqi")
    public suspend fun subscriptions(values: List<Output<ResourceIdArgs>>) {
        this.subscriptions = Output.all(values)
    }

    /**
     * @param value The collection of virtual nets covered by the Managed Network
     */
    @JvmName("mjgmvfqjigtqowwb")
    public suspend fun virtualNetworks(`value`: Output<List<ResourceIdArgs>>) {
        this.virtualNetworks = value
    }

    @JvmName("axawkpnjbbnsisjp")
    public suspend fun virtualNetworks(vararg values: Output<ResourceIdArgs>) {
        this.virtualNetworks = Output.all(values.asList())
    }

    /**
     * @param values The collection of virtual nets covered by the Managed Network
     */
    @JvmName("pdkqijnnnxkvepdu")
    public suspend fun virtualNetworks(values: List<Output<ResourceIdArgs>>) {
        this.virtualNetworks = Output.all(values)
    }

    /**
     * @param value The collection of management groups covered by the Managed Network
     */
    @JvmName("xnsybumbimasgexr")
    public suspend fun managementGroups(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param argument The collection of management groups covered by the Managed Network
     */
    @JvmName("dtgtogtraeemakmu")
    public suspend fun managementGroups(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.managementGroups = mapped
    }

    /**
     * @param argument The collection of management groups covered by the Managed Network
     */
    @JvmName("xorqkvxpcrpnrwhf")
    public suspend fun managementGroups(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.managementGroups = mapped
    }

    /**
     * @param argument The collection of management groups covered by the Managed Network
     */
    @JvmName("ghhwevymulmjddqu")
    public suspend fun managementGroups(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.managementGroups = mapped
    }

    /**
     * @param values The collection of management groups covered by the Managed Network
     */
    @JvmName("pyqsjmqmforyqkik")
    public suspend fun managementGroups(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value The collection of  subnets covered by the Managed Network
     */
    @JvmName("bltptjucueiryohy")
    public suspend fun subnets(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnets = mapped
    }

    /**
     * @param argument The collection of  subnets covered by the Managed Network
     */
    @JvmName("vfhccfbutytewauq")
    public suspend fun subnets(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.subnets = mapped
    }

    /**
     * @param argument The collection of  subnets covered by the Managed Network
     */
    @JvmName("gasuiocbpoktkovj")
    public suspend fun subnets(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.subnets = mapped
    }

    /**
     * @param argument The collection of  subnets covered by the Managed Network
     */
    @JvmName("xagukgqwtxamarcy")
    public suspend fun subnets(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.subnets = mapped
    }

    /**
     * @param values The collection of  subnets covered by the Managed Network
     */
    @JvmName("efgieigfyedpalwh")
    public suspend fun subnets(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subnets = mapped
    }

    /**
     * @param value The collection of subscriptions covered by the Managed Network
     */
    @JvmName("njjufqsgtlrhtfqm")
    public suspend fun subscriptions(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptions = mapped
    }

    /**
     * @param argument The collection of subscriptions covered by the Managed Network
     */
    @JvmName("sofjespcpjjbndmy")
    public suspend fun subscriptions(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.subscriptions = mapped
    }

    /**
     * @param argument The collection of subscriptions covered by the Managed Network
     */
    @JvmName("ujqpfbgctwbvcoja")
    public suspend fun subscriptions(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.subscriptions = mapped
    }

    /**
     * @param argument The collection of subscriptions covered by the Managed Network
     */
    @JvmName("hjqjgsgcvjoktoeq")
    public suspend fun subscriptions(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.subscriptions = mapped
    }

    /**
     * @param values The collection of subscriptions covered by the Managed Network
     */
    @JvmName("wcoosocnrfqifita")
    public suspend fun subscriptions(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptions = mapped
    }

    /**
     * @param value The collection of virtual nets covered by the Managed Network
     */
    @JvmName("untrsqthjblduphk")
    public suspend fun virtualNetworks(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNetworks = mapped
    }

    /**
     * @param argument The collection of virtual nets covered by the Managed Network
     */
    @JvmName("ujnhdrgojuevcgwt")
    public suspend fun virtualNetworks(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.virtualNetworks = mapped
    }

    /**
     * @param argument The collection of virtual nets covered by the Managed Network
     */
    @JvmName("yetdhhiqcscjvfjc")
    public suspend fun virtualNetworks(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.virtualNetworks = mapped
    }

    /**
     * @param argument The collection of virtual nets covered by the Managed Network
     */
    @JvmName("dgtjowjthfbrssgg")
    public suspend fun virtualNetworks(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.virtualNetworks = mapped
    }

    /**
     * @param values The collection of virtual nets covered by the Managed Network
     */
    @JvmName("vyojdfidnpokpjdd")
    public suspend fun virtualNetworks(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworks = mapped
    }

    internal fun build(): ScopeArgs = ScopeArgs(
        managementGroups = managementGroups,
        subnets = subnets,
        subscriptions = subscriptions,
        virtualNetworks = virtualNetworks,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/managednetwork/kotlin/inputs/ScopeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetwork.kotlin.inputs

import com.pulumi.azurenative.managednetwork.inputs.ScopeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Scope of a Managed Network
 * @property managementGroups The collection of management groups covered by the Managed Network
 * @property subnets The collection of  subnets covered by the Managed Network
 * @property subscriptions The collection of subscriptions covered by the Managed Network
 * @property virtualNetworks The collection of virtual nets covered by the Managed Network
 */
public data class ScopeArgs(
    public val managementGroups: Output<List<ResourceIdArgs>>? = null,
    public val subnets: Output<List<ResourceIdArgs>>? = null,
    public val subscriptions: Output<List<ResourceIdArgs>>? = null,
    public val virtualNetworks: Output<List<ResourceIdArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetwork.inputs.ScopeArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetwork.inputs.ScopeArgs =
        com.pulumi.azurenative.managednetwork.inputs.ScopeArgs.builder()
            .managementGroups(
                managementGroups?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .subnets(
                subnets?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .subscriptions(
                subscriptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .virtualNetworks(
                virtualNetworks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ScopeArgs].
 */
@PulumiTagMarker
public class ScopeArgsBuilder internal constructor() {
    private var managementGroups: Output<List<ResourceIdArgs>>? = null

    private var subnets: Output<List<ResourceIdArgs>>? = null

    private var subscriptions: Output<List<ResourceIdArgs>>? = null

    private var virtualNetworks: Output<List<ResourceIdArgs>>? = null

    /**
     * @param value The collection of management groups covered by the Managed Network
     */
    @JvmName("urujtonnwnexyyor")
    public suspend fun managementGroups(`value`: Output<List<ResourceIdArgs>>) {
        this.managementGroups = value
    }

    @JvmName("qohmfmyvrbwamvaa")
    public suspend fun managementGroups(vararg values: Output<ResourceIdArgs>) {
        this.managementGroups = Output.all(values.asList())
    }

    /**
     * @param values The collection of management groups covered by the Managed Network
     */
    @JvmName("osuktuaqnoyrjesf")
    public suspend fun managementGroups(values: List<Output<ResourceIdArgs>>) {
        this.managementGroups = Output.all(values)
    }

    /**
     * @param value The collection of  subnets covered by the Managed Network
     */
    @JvmName("dilvqhownrknwcgl")
    public suspend fun subnets(`value`: Output<List<ResourceIdArgs>>) {
        this.subnets = value
    }

    @JvmName("yomaqgwplwbdjlub")
    public suspend fun subnets(vararg values: Output<ResourceIdArgs>) {
        this.subnets = Output.all(values.asList())
    }

    /**
     * @param values The collection of  subnets covered by the Managed Network
     */
    @JvmName("fvuijaateplgcifk")
    public suspend fun subnets(values: List<Output<ResourceIdArgs>>) {
        this.subnets = Output.all(values)
    }

    /**
     * @param value The collection of subscriptions covered by the Managed Network
     */
    @JvmName("hiusosxaehamaafp")
    public suspend fun subscriptions(`value`: Output<List<ResourceIdArgs>>) {
        this.subscriptions = value
    }

    @JvmName("gnqfkbavpvgixprm")
    public suspend fun subscriptions(vararg values: Output<ResourceIdArgs>) {
        this.subscriptions = Output.all(values.asList())
    }

    /**
     * @param values The collection of subscriptions covered by the Managed Network
     */
    @JvmName("eflpelnusioikcxi")
    public suspend fun subscriptions(values: List<Output<ResourceIdArgs>>) {
        this.subscriptions = Output.all(values)
    }

    /**
     * @param value The collection of virtual nets covered by the Managed Network
     */
    @JvmName("yqqxfxtaijkeggad")
    public suspend fun virtualNetworks(`value`: Output<List<ResourceIdArgs>>) {
        this.virtualNetworks = value
    }

    @JvmName("xbkipuqgjvwlauxa")
    public suspend fun virtualNetworks(vararg values: Output<ResourceIdArgs>) {
        this.virtualNetworks = Output.all(values.asList())
    }

    /**
     * @param values The collection of virtual nets covered by the Managed Network
     */
    @JvmName("vuyyrgioglcvuewe")
    public suspend fun virtualNetworks(values: List<Output<ResourceIdArgs>>) {
        this.virtualNetworks = Output.all(values)
    }

    /**
     * @param value The collection of management groups covered by the Managed Network
     */
    @JvmName("qabtlldempkjsias")
    public suspend fun managementGroups(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param argument The collection of management groups covered by the Managed Network
     */
    @JvmName("fgpuppxmxrdeydhf")
    public suspend fun managementGroups(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.managementGroups = mapped
    }

    /**
     * @param argument The collection of management groups covered by the Managed Network
     */
    @JvmName("eefxmefpwubfsnep")
    public suspend fun managementGroups(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.managementGroups = mapped
    }

    /**
     * @param argument The collection of management groups covered by the Managed Network
     */
    @JvmName("jmqtqvwvujttkiqd")
    public suspend fun managementGroups(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.managementGroups = mapped
    }

    /**
     * @param values The collection of management groups covered by the Managed Network
     */
    @JvmName("iyfufchcrycqrnij")
    public suspend fun managementGroups(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.managementGroups = mapped
    }

    /**
     * @param value The collection of  subnets covered by the Managed Network
     */
    @JvmName("iwnkpesnxoynjwef")
    public suspend fun subnets(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnets = mapped
    }

    /**
     * @param argument The collection of  subnets covered by the Managed Network
     */
    @JvmName("xgjmjymdgmwtyogq")
    public suspend fun subnets(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.subnets = mapped
    }

    /**
     * @param argument The collection of  subnets covered by the Managed Network
     */
    @JvmName("aiakpyhucuuqintu")
    public suspend fun subnets(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.subnets = mapped
    }

    /**
     * @param argument The collection of  subnets covered by the Managed Network
     */
    @JvmName("qnjnoqurwbyeuxyc")
    public suspend fun subnets(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.subnets = mapped
    }

    /**
     * @param values The collection of  subnets covered by the Managed Network
     */
    @JvmName("auhnlcnalqytbpep")
    public suspend fun subnets(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subnets = mapped
    }

    /**
     * @param value The collection of subscriptions covered by the Managed Network
     */
    @JvmName("mhadkmsvawekopid")
    public suspend fun subscriptions(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptions = mapped
    }

    /**
     * @param argument The collection of subscriptions covered by the Managed Network
     */
    @JvmName("pjcxppojsjnacygp")
    public suspend fun subscriptions(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.subscriptions = mapped
    }

    /**
     * @param argument The collection of subscriptions covered by the Managed Network
     */
    @JvmName("lqpgmlgjjsbvqqve")
    public suspend fun subscriptions(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.subscriptions = mapped
    }

    /**
     * @param argument The collection of subscriptions covered by the Managed Network
     */
    @JvmName("qosrhegqcohdfuoj")
    public suspend fun subscriptions(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.subscriptions = mapped
    }

    /**
     * @param values The collection of subscriptions covered by the Managed Network
     */
    @JvmName("ntssdetumelltlgt")
    public suspend fun subscriptions(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptions = mapped
    }

    /**
     * @param value The collection of virtual nets covered by the Managed Network
     */
    @JvmName("dlagxybcfnvgntqg")
    public suspend fun virtualNetworks(`value`: List<ResourceIdArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNetworks = mapped
    }

    /**
     * @param argument The collection of virtual nets covered by the Managed Network
     */
    @JvmName("gqsyrvcwktegnkob")
    public suspend fun virtualNetworks(argument: List<suspend ResourceIdArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.virtualNetworks = mapped
    }

    /**
     * @param argument The collection of virtual nets covered by the Managed Network
     */
    @JvmName("eebqfaddavrsqdra")
    public suspend fun virtualNetworks(vararg argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ResourceIdArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.virtualNetworks = mapped
    }

    /**
     * @param argument The collection of virtual nets covered by the Managed Network
     */
    @JvmName("hvpsduuyktsnrdsg")
    public suspend fun virtualNetworks(argument: suspend ResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceIdArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.virtualNetworks = mapped
    }

    /**
     * @param values The collection of virtual nets covered by the Managed Network
     */
    @JvmName("krbsdljeegdvwnqo")
    public suspend fun virtualNetworks(vararg values: ResourceIdArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworks = mapped
    }

    internal fun build(): ScopeArgs = ScopeArgs(
        managementGroups = managementGroups,
        subnets = subnets,
        subscriptions = subscriptions,
        virtualNetworks = virtualNetworks,
    )
}
